# $Header: space.def.s,v 1.5 00/01/31 13:53:21 space Exp $
#
# space element definition file for scmos_n example process
# with transistor bulk connections and substrate terminals 
# for substrate contacts and nmos bulk connections, and
# with information for 3D capacitance extraction and 
# substrate resistance extraction.
#
# masks:
# cpg - polysilicon interconnect        ccp - contact metal to poly
# caa - active area                     cva - contact metal to metal2
# cmf - metal interconnect              cwn - n-well
# cms - metal2 interconnect             csn - n-channel implant
# cca - contact metal to diffusion      cog - contact to bondpads
#
# See also: maskdata

unit resistance    1     # Oh
unit c_resistance  1e-12 # Ohm um^2
unit a_capacitance 1e-6  # aF/um^2
unit e_capacitance 1e-12 # aF/um
unit capacitance   1e-15 # fF
unit vdimension    1e-6  # um
unit shape         1e-6  # um

maxkeys 13

colors :
    cpg   red
    caa   green
    cmf   blue
    cms   gold
    cca   black
    ccp   black
    cva   black
    cwn   glass
    csn   glass
    cog   glass
    cx    glass
    @sub  pink

conductors :
  # name    : condition     : mask : resistivity : type
    cond_mf : cmf           : cmf  : 0.045       : m    # first metal
    cond_ms : cms           : cms  : 0.030       : m    # second metal
    cond_pg : cpg           : cpg  : 40          : m    # poly interc.
    cond_pa : caa !cpg !csn : caa  : 70          : p    # p+ active area
    cond_na : caa !cpg  csn : caa  : 50          : n    # n+ active area
    cond_well : cwn         : cwn  : 0           : n    # n well

fets :
  # name : condition    : gate d/s : bulk
    nenh : cpg caa  csn : cpg  caa : @sub  # nenh MOS
    penh : cpg caa !csn : cpg  caa : cwn   # penh MOS

contacts :
  # name   : condition         : lay1 lay2 : resistivity
    cont_s : cva cms cmf       : cms  cmf  :   1   # metal to metal2
    cont_p : ccp cmf cpg       : cmf  cpg  : 100   # metal to poly
    cont_a : cca cmf caa !cpg cwn !csn
           | cca cmf caa !cpg !cwn csn
                               : cmf  caa  : 100   # metal to act. area

    cont_w : cca cmf cwn csn   : cmf  cwn  :  80   # metal to well
    cont_b : cca cmf !cwn !csn : cmf  @sub :  80   # metal to subs

junction capacitances ndif :
  # name    :  condition                 : mask1 mask2 : capacitivity
    acap_na :  caa  !cpg  csn !cwn       : @gnd caa  : 100  # bottom
    ecap_na : !caa !-cpg -csn !-cwn -caa : @gnd -caa : 300  # sidewall

junction capacitances nwell :
    acap_cw :  cwn                  : @gnd cwn  : 100  # bottom
    ecap_cw : !cwn -cwn             : @gnd -cwn : 800  # sidewall

junction capacitances pdif :
    acap_pa :  caa  !cpg  !csn cwn           :  caa cwn : 500 # bottom
    ecap_pa : !caa !-cpg !-csn cwn -cwn -caa : -caa cwn : 600 # sidewall

capacitances :
  # polysilicon capacitances
    acap_cpg_sub :  cpg                !caa !cwn :  cpg @gnd : 49
    acap_cpg_cwn :  cpg                !caa  cwn :  cpg cwn  : 49 
    ecap_cpg_sub : !cpg -cpg !cmf !cms !caa !cwn : -cpg @gnd : 52
    ecap_cpg_cwn : !cpg -cpg !cmf !cms !caa  cwn : -cpg cwn  : 52

  # first metal capacitances
    acap_cmf_sub :  cmf           !cpg !caa !cwn :  cmf @gnd : 25
    acap_cmf_cwn :  cmf           !cpg !caa cwn  :  cmf cwn  : 25
    ecap_cmf_sub : !cmf -cmf !cms !cpg !caa !cwn : -cmf @gnd : 52
    ecap_cmf_cwn : !cmf -cmf !cms !cpg !caa cwn  : -cmf cwn  : 52

    acap_cmf_caa :  cmf      caa !cpg !cca !cca :  cmf  caa : 49
    ecap_cmf_caa : !cmf -cmf caa !cms !cpg      : -cmf  caa : 59

    acap_cmf_cpg :  cmf      cpg !ccp :  cmf  cpg : 49
    ecap_cmf_cpg : !cmf -cmf cpg !cms : -cmf  cpg : 59

  # second metal capacitances
    acap_cms_sub :  cms      !cmf !cpg !caa !cwn :  cms @gnd : 16
    acap_cms_cwn :  cms      !cmf !cpg !caa cwn  :  cms cwn  : 16
    ecap_cms_sub : !cms -cms !cmf !cpg !caa !cwn : -cms @gnd : 51
    ecap_cms_cwn : !cms -cms !cmf !cpg !caa cwn  : -cms cwn  : 51

    acap_cms_caa :  cms      caa !cmf !cpg :  cms caa : 25
    ecap_cms_caa : !cms -cms caa !cmf !cpg : -cms caa : 54

    acap_cms_cpg :  cms      cpg !cmf :  cms cpg : 25
    ecap_cms_cpg : !cms -cms cpg !cmf : -cms cpg : 54

    acap_cms_cmf :  cms      cmf !cva :  cms cmf : 49
    ecap_cms_cmf : !cms -cms cmf      : -cms cmf : 61

    lcap_cms     : !cms -cms =cms      : -cms =cms : 0.07

vdimensions :
    v_caa_on_all : caa !cpg           : caa : 0.30 0.00
    v_cpg_of_caa : cpg !caa           : cpg : 0.60 0.50
    v_cpg_on_caa : cpg caa            : cpg : 0.35 0.70
    v_cmf        : cmf                : cmf : 1.70 0.70
    v_cms        : cms                : cms : 2.80 0.70
    
dielectrics :
   # Dielectric consists of 5 micron thick SiO2
   # (epsilon = 3.9) on a conducting plane.
   SiO2   3.9   0.0
   air    1.0   5.0

sublayers :
  # name       conductivity  top
    substrate  6.7           0.0

selfsubres :
  # resistances to substrate node
  # area per.  val.  rest
    1.0  4.0  65851  0.5
    4.0  8.0  32937  0.5
    16.0 16.0 16480  0.5

coupsubres:
  # direct coupling resistances
  # area1 area2 dist   val.   decr.
    1.0   1.0  1.0   338990  0.800
    1.0   1.0  2.0   529316  0.872
    1.0   1.0  4.0   898693  0.922
    1.0   1.0  8.0  1628779  0.951

#EOF
